(*

This is the top-level file for the interpreter.  To run MiniML, start
up sml and then "use" this file:

% sml
Standard ML of New Jersey, Version 110.0.3, January 30, 1998 [CM; autoload enabled]
- use "interpreter.sml";
.... lots of compilation output ....

This file invokes CM.make(), which uses the sources.cm file to compile
all the parts of the interpreter (skipping over anything that hasn't
changed and doesn't depend on anything that's changed) and then load
them into the interpreter.  It then starts up the interpreter's
read-eval-print loop:

....
Welcome to MiniML!
Enter the input declaration or expression to be evaluated.
Full type inference is supported.
(<, <=, >=, and > are no longer supported on strings.)
Enter a blank line to exit.

MiniML - 

If you make any changes to any files of the interpreter, just re-"use"
this file (at the sml - prompt, not the MiniML prompt!), and all will
be recompiled and reloaded, and the MiniML read-eval-print loop will
be started again.

If you want to make a stand-alone executable of the interpreter, exit
MiniML, and at the sml - prompt, invoke make_standalone_executable():

MiniML - 
Thanks for playing.  Please come again soon!
val it = () : unit
val it = () : unit
- make_standalone_executable();
.... lots of output ....
%

Now there's a file named MiniML.<arch>-<os>, for the <arch> and <os>
you're running on.  To invoke it later, pass the
@SMLload=MiniML.<arch>-<os> argument to sml, e.g.:

% sml @SMLload=MiniML.sparc-solaris

Welcome to MiniML!
Enter the input declaration or expression to be evaluated.
Full type inference is supported.
(<, <=, >=, and > are no longer supported on strings.)
Enter a blank line to exit.

MiniML - 

*)

(* Turn off garbage collection messages *)
SMLofNJ.Internals.GC.messages(false);

(* compile all the source files *)
CM.make();

(* define a function that's the program to run *)
fun repl() = print(Repl.repl());

(* define a main function, to use when building a "standalone" executable *)
fun main(arg0:string, args:string list):OS.Process.status =
  (repl(); OS.Process.success)

(* invoke this from the ML command line to create a standalone
   executable named MiniML: *)
fun make_standalone_executable() =
  SMLofNJ.exportFn("MiniML", main);

(* now start things up *)
repl();
